==> nextcloud-16.0.7.tar.bz2: nextcloud/apps/workflowengine/l10n/zh_CN.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "给定的运算符无效",
    "The given regular expression is invalid" : "给定的正则表达式无效",
    "The given file size is invalid" : "给定的文件大小无效",
    "The given tag id is invalid" : "给定的标签 ID 无效",
    "The given IP range is invalid" : "给定的IP范围无效",
    "The given IP range is not valid for IPv4" : "填写的 IP 范围不是有效的 IPv4 格式",
    "The given IP range is not valid for IPv6" : "填写的 IP 范围不是有效的 IPv6 格式",
    "The given time span is invalid" : "给定的时间范围无效",
    "The given start time is invalid" : "给定的开始时间无效",
    "The given end time is invalid" : "输入的截止时间无效",
    "The given group does not exist" : "输入的群组不存在",
    "File" : "文件",
    "File created" : "已创建的文件",
    "File updated" : "文件已更新",
    "File renamed" : "重命名的文件",
    "File deleted" : "已删除文件",
    "File accessed" : "已访问的文件",
    "File copied" : "已复制的文件",
    "Tag assigned" : "已指派的标签",
    "Someone" : "某人",
    "%s created %s" : "%s 创建了 %s",
    "%s modified %s" : "%s 修改了 %s",
    "%s deleted %s" : "%s 删除了 %s",
    "%s accessed %s" : "%s 访问了 %s",
    "%s renamed %s" : "%s 重命名了 %s",
    "%s copied %s" : "%s 复制了 %s",
    "%s assigned %s to %s" : "%s 分配了 %s 给 %s",
    "Operation #%s does not exist" : "操作 %s 不存在",
    "Entity %s does not exist" : "实体%s不存在",
    "Entity %s is invalid" : "实体%s是无效的",
    "No events are chosen." : "没有事件被选中。",
    "Entity %s has no event %s" : "实体%s没有事件%s",
    "Operation %s does not exist" : "操作 %s 不存在",
    "Operation %s is invalid" : "操作 %s 无效",
    "Check %s does not exist" : "检查 %s 不存在",
    "Check %s is invalid" : "检查%s是不可用",
    "Check %s is not allowed with this entity" : "对于此实体，检查%s是不被允许的",
    "Check #%s does not exist" : "检查 #%s 不存在",
    "Check %s is invalid or does not exist" : "检查%s是不可用或者不存在",
    "Flow" : "流程",
    "Nextcloud workflow engine" : "Nextcloud 工作流引擎",
    "Select a filter" : "选择一个过滤器",
    "Select a comparator" : "选择一个比较器",
    "Select a file type" : "选择一个文件类型",
    "e.g. httpd/unix-directory" : "例如： httpd/unix-directory",
    "Images" : "图片",
    "Office documents" : "Office 文档",
    "PDF documents" : "PDF文档",
    "Custom mimetype" : "自定义MIME类型",
    "Select a tag" : "选择标签",
    "No results" : "没有结果",
    "%s (invisible)" : "%s（不可见）",
    "%s (restricted)" : "%s（受限）",
    "Please enter a valid time span" : "请输入有效的时间范围",
    "Select a request URL" : "选择一个请求URL",
    "Predefined URLs" : "预定义 URL",
    "Files WebDAV" : "文件 WebDAV",
    "Others" : "其它",
    "Custom URL" : "自定义URL",
    "Select a user agent" : "选择一个用户代理",
    "Android client" : "Android 客户端",
    "iOS client" : "iOS 客户端",
    "Desktop client" : "桌面客户端",
    "Thunderbird & Outlook addons" : "Thunderbird & Outlook 插件",
    "Custom user agent" : "自定义用户代理",
    "Add new flow" : "添加新的流程",
    "When" : "时间",
    "and" : "与",
    "Cancel" : "取消",
    "Delete" : "删除",
    "The configuration is invalid" : "此配置是无效的",
    "Active" : "活动",
    "Save" : "保存",
    "Available flows" : "可用的流程",
    "For details on how to write your own flow, check out the development documentation." : "有关如何编写自己的流程的详细信息，请查看开发文档。",
    "More flows" : "更多流程",
    "Browse the app store" : "浏览应用商店",
    "Show less" : "显示更少",
    "Show more" : "显示更多",
    "Configured flows" : "已配置的流程",
    "Your flows" : "你的流程",
    "File name" : "文件名",
    "is" : "是",
    "is not" : "不是",
    "matches" : "匹配",
    "does not match" : "不匹配",
    "File MIME type" : "文件 MIME 类型",
    "File size (upload)" : "文件大小 (上传)",
    "less" : "小于",
    "less or equals" : "小于等于",
    "greater or equals" : "大于等于",
    "greater" : "大于",
    "Request remote address" : "要求远程地址",
    "matches IPv4" : "匹配 IPv4",
    "does not match IPv4" : "不匹配 IPv4",
    "matches IPv6" : "匹配 IPv6",
    "does not match IPv6" : "不匹配 IPv6",
    "File system tag" : "文件系统标签",
    "is tagged with" : "标记为",
    "is not tagged with" : "未标记为",
    "Request URL" : "请求 URL",
    "Request time" : "请求时间",
    "between" : "之间",
    "not between" : "不在之间",
    "Request user agent" : "请求用户代理",
    "User group membership" : "用户组成员资格",
    "is member of" : "是成员",
    "is not member of" : "不是成员",
    "Short rule description" : "短规则说明",
    "Add rule" : "添加规则",
    "Reset" : "重置",
    "Saving…" : "保存中...",
    "Group list is empty" : "用户群组列表空",
    "Unable to retrieve the group list" : "无法获取用户群组列表",
    "Saved" : "已保存",
    "Saving failed:" : "保存失败：",
    "Add rule group" : "添加规则组",
    "Example: {placeholder}" : "例子：{placeholder}",
    "Select tag…" : "选择标签...",
    "Start" : "开始",
    "End" : "结束",
    "Select timezone…" : "选择时区...",
    "Sync clients" : "同步客户端",
    "Workflow" : "工作流",
    "Files workflow engine" : "文件工作流引擎",
    "Open documentation" : "打开文档",
    "Loading…" : "加载中...",
    "Tag management" : "标签管理"
},
"nplurals=1; plural=0;");

==> nextcloud-32.0.0.tar.bz2: nextcloud/apps/workflowengine/l10n/zh_CN.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "给定的运算符无效",
    "The given regular expression is invalid" : "给定的正则表达式无效",
    "The given file size is invalid" : "给定的文件大小无效",
    "The given tag id is invalid" : "给定的标签 ID 无效",
    "The given IP range is invalid" : "给定的IP范围无效",
    "The given IP range is not valid for IPv4" : "填写的 IP 范围不是有效的 IPv4 格式",
    "The given IP range is not valid for IPv6" : "填写的 IP 范围不是有效的 IPv6 格式",
    "The given time span is invalid" : "给定的时间范围无效",
    "The given start time is invalid" : "给定的开始时间无效",
    "The given end time is invalid" : "输入的截止时间无效",
    "The given group does not exist" : "输入的群组不存在",
    "File" : "文件",
    "File created" : "已创建的文件",
    "File updated" : "文件已更新",
    "File renamed" : "重命名的文件",
    "File deleted" : "已删除文件",
    "File accessed" : "已访问的文件",
    "File copied" : "已复制的文件",
    "Tag assigned" : "已指派的标签",
    "Someone" : "某人",
    "%s created %s" : "%s 创建了 %s",
    "%s modified %s" : "%s 修改了 %s",
    "%s deleted %s" : "%s 删除了 %s",
    "%s accessed %s" : "%s 访问了 %s",
    "%s renamed %s" : "%s 重命名了 %s",
    "%s copied %s" : "%s 复制了 %s",
    "%s assigned %s to %s" : "%s 分配了 %s 给 %s",
    "Operation #%s does not exist" : "操作 %s 不存在",
    "Entity %s does not exist" : "实体%s不存在",
    "Entity %s is invalid" : "实体%s是无效的",
    "No events are chosen." : "没有事件被选中。",
    "Entity %s has no event %s" : "实体%s没有事件%s",
    "Operation %s does not exist" : "操作 %s 不存在",
    "Operation %s is invalid" : "操作 %s 无效",
    "At least one check needs to be provided" : "至少需要提供一次检查",
    "The provided operation data is too long" : "提供的操作数据太长",
    "Invalid check provided" : "提供的检查无效",
    "Check %s does not exist" : "检查 %s 不存在",
    "Check %s is invalid" : "检查%s是不可用",
    "Check %s is not allowed with this entity" : "对于此实体，检查%s是不被允许的",
    "The provided check value is too long" : "提供的检查值太长",
    "Check #%s does not exist" : "检查 #%s 不存在",
    "Check %s is invalid or does not exist" : "检查%s是不可用或者不存在",
    "Flow" : "流程",
    "Nextcloud workflow engine" : "Nextcloud 工作流引擎",
    "Select a filter" : "选择一个过滤器",
    "Select a comparator" : "选择一个比较器",
    "Remove filter" : "移除过滤条件",
    "Audio" : "音频",
    "Folder" : "文件夹",
    "Images" : "图片",
    "Office documents" : "Office 文档",
    "PDF documents" : "PDF文档",
    "Video" : "视频",
    "Custom MIME type" : "自定义 MIME 类型",
    "Custom mimetype" : "自定义MIME类型",
    "Select a file type" : "选择一个文件类型",
    "e.g. httpd/unix-directory" : "例如： httpd/unix-directory",
    "Please enter a valid time span" : "请输入有效的时间范围",
    "Files WebDAV" : "文件 WebDAV",
    "Custom URL" : "自定义URL",
    "Select a request URL" : "选择一个请求URL",
    "Android client" : "Android 客户端",
    "iOS client" : "iOS 客户端",
    "Desktop client" : "桌面客户端",
    "Thunderbird & Outlook addons" : "Thunderbird & Outlook 插件",
    "Custom user agent" : "自定义用户代理",
    "Select a user agent" : "选择一个用户代理",
    "Select groups" : "选择用户组",
    "Groups" : "用户组",
    "Type to search for group …" : "输入以搜索群组...",
    "Select a trigger" : "选择一个触发器",
    "At least one event must be selected" : "必须至少选择一个事件",
    "Add new flow" : "添加新的流程",
    "The configuration is invalid" : "此配置是无效的",
    "Active" : "作用",
    "Save" : "保存",
    "When" : "时间",
    "and" : "与",
    "Add a new filter" : "添加一个新的筛选条件",
    "Cancel" : "取消",
    "Delete" : "删除",
    "Available flows" : "可用的流程",
    "For details on how to write your own flow, check out the development documentation." : "有关如何编写自己的流程的详细信息，请查看开发文档。",
    "No flows installed" : "未安装任何流量设备",
    "Ask your administrator to install new flows." : "请让你的管理员安装新的流量设备。",
    "More flows" : "更多流程",
    "Browse the App Store" : "浏览应用商店",
    "Show less" : "显示更少",
    "Show more" : "显示更多",
    "Configured flows" : "已配置的流程",
    "Your flows" : "你的流程",
    "No flows configured" : "未配置任何流程",
    "matches" : "匹配",
    "does not match" : "不匹配",
    "is" : "是",
    "is not" : "不是",
    "File name" : "文件名",
    "File MIME type" : "文件 MIME 类型",
    "File size (upload)" : "文件大小 (上传)",
    "less" : "小于",
    "less or equals" : "小于等于",
    "greater or equals" : "大于等于",
    "greater" : "大于",
    "Request remote address" : "要求远程地址",
    "matches IPv4" : "匹配 IPv4",
    "does not match IPv4" : "不匹配 IPv4",
    "matches IPv6" : "匹配 IPv6",
    "does not match IPv6" : "不匹配 IPv6",
    "File system tag" : "文件系统标签",
    "is tagged with" : "标记为",
    "is not tagged with" : "未标记为",
    "Request URL" : "请求 URL",
    "Request time" : "请求时间",
    "between" : "之间",
    "not between" : "不在之间",
    "Request user agent" : "请求用户代理",
    "Group membership" : "组成员资格",
    "is member of" : "是成员",
    "is not member of" : "不是成员"
},
"nplurals=1; plural=0;");
